GeneratorUtils class

Utility functions for code generation

Constructors

GeneratorUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractParametersFromPath(String path) PathParameters
Extract parameters from route path
generateDocComment(RouteInfo routeInfo) String
Generate documentation comment
generateMethodName(String path, String prefix) String
Generate method name from path
getDartType(TypeParameterElement parameter) String
Get Dart type from parameter element
isNullable(TypeParameterElement parameter) bool
Check if parameter is nullable
pathToClassName(String path) String
Convert path to valid class name
toCamelCase(String input) String
Convert parameter name to camelCase
toPascalCase(String input) String
Convert string to PascalCase
validatePath(String path) List<String>
Validate route path format