ResolvedRouteInfo class

Constructors

ResolvedRouteInfo({required RouteInfo info, required String navigableFullPath, required String parentNavigablePath, required List<String> fullRequiredParams, required List<String> fullOptionalParams})

Properties

fullOptionalParams List<String>
final
fullRequiredParams List<String>
final
hashCode int
The hash code for this object.
no setterinherited
info RouteInfo
final
final
parentNavigablePath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited