RouteGraph class
Constructors
-
RouteGraph({required List<
ResolvedRouteInfo> routes, required List<ResolvedShellInfo> shells})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routes
→ List<
ResolvedRouteInfo> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shells
→ List<
ResolvedShellInfo> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited