RouteInfo class

Constructors

RouteInfo({required String className, required String path, String? name, String? description, required List<String> middleware, required List<FormalParameterElement> constructorParams, String? importPath, String? parent, int? order, required List<String> requiredParams, required List<String> optionalParams})
const

Properties

className String
final
constructorParams List<FormalParameterElement>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
importPath String?
final
middleware List<String>
final
name String?
final
optionalParams List<String>
final
order int?
final
parent String?
final
path String
final
requiredParams List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited