ShellInfo class

Constructors

ShellInfo({required String className, required String path, String? name, String? description, String? navigatorKey, String? importPath, String? parent, required bool isStateful, String? initialRoute, int? order, String? pageBuilder})
const

Properties

className String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
importPath String?
final
initialRoute String?
final
isStateful bool
final
name String?
final
final
order int?
final
pageBuilder String?
final
parent String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited